# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .models import (
    Reference,
    ReferencePlugin as ReferencePluginModel,
)


class ReferencePlugin(CMSPluginBase):
    model = ReferencePluginModel
    name = _('Reference plugin')
    render_template = 'reference_cmsplugin/reference_list.html'

    def render(self, context, instance, placeholder):
        categories = instance.categories.enabled()
        references = Reference.objects.enabled().filter(
            categories__in=instance.categories.enabled(),
        ).distinct()

        context.update({
            'instance': instance,
            'categories': categories,
            'references': references,
        })
        return context


plugin_pool.register_plugin(ReferencePlugin)
